emperor.nbinstall — Emperor 0.9.51-dev documentation

# emperor.nbinstall

`emperor.` `nbinstall`(overwrite=False, user=True, prefix=None)

  Copies resources to the ‘/nbextensions’ folder in your IPython directory

  This function was taken from [1] and modified to match our usecase.

  Parameters: | overwrite : bool, optional If True, always install the files, regardless of what may already be installed. Defaults to False. user : bool, optional Whether to install to the user’s .ipython/nbextensions directory. Otherwise do a system-wide install (e.g. /usr/local/share/jupyter/nbextensions/emperor). Defaults to False. prefix : str, optional Where the files are copied to, by default they are copied to the appropriate Jupyter/IPython folder, alternatively it can be a folder where the resources are copied to. Note, that if this parameter is set user has to be None.
  Raises: | ArgumentConflict When prefix and user are used together.

  Notes

  After you install emperor, call this function once before attempting to call `Emperor` in the Jupyter notebook.

  References

  [R4] | GitHub repository for qgrid https://github.com/quantopian/qgrid